/* Birth weight report with page numbers and headings */

version 17
use low, clear

/* Create a document with a footer */
putdocx begin, footer(foot1)

/* Add a paragraph to the footer */
putdocx paragraph, tofooter(foot1)
putdocx text ("Page ")
putdocx pagenumber

/* Add a title */
putdocx paragraph, style(Title)
putdocx text ("Analysis of birthweights")

/* Add the following content on a new page */
putdocx pagebreak

/* Add a heading for the section on data */
putdocx paragraph, style(Heading1)
putdocx text ("Data")

/* Add a description of the data */
putdocx textblock begin
We have data on birthweights from Hosmer, Lemeshow, and Sturdivant(2013, 24). This dataset includes some demographic information on each infant's mother, 
such as her age and race. We also have relevant medical history, including her 
weight, history of hypertension and premature labor, and the number of physician 
visits during her first trimester.
putdocx textblock end

/* Add a heading for the section on summary statistics */
putdocx paragraph, style(Heading1)
putdocx text ("Summary statistics")

summarize bwt
local total = r(N)
putdocx textblock begin
We have the recorded weight for <<dd_docx_display: r(N)>> babies with an 
average birthweight of <<dd_docx_display: %5.2f r(mean)>> grams.
putdocx textblock end
count if smoke==1

/* Add a description of the graph */
putdocx textblock append
 There are <<dd_docx_display: r(N)>> mothers who smoked during pregnancy, and <<dd_docx_display: `total'-r(N)>> who did not. Below we graph the mean 
birthweight for babies with mothers who smoke versus those who do not, 
separately for mothers with and without a history of hypertension.
putdocx textblock end

/* Add a title and subtitle to the graph, and modify the y-axis title */
graph hbar bwt, over(ht) over(smoke) asyvars ///
 title(Baby birthweights) ytitle(Average birthweight (grams)) ///
 subtitle(by mother's smoking status and history of hypertension)
graph export bweight.png, replace

putdocx paragraph
// Specify the width of the image
putdocx image bweight.png, width(4) 

/* Add the following content on a new page */
putdocx pagebreak

/* Add a heading for the section on regression results */
putdocx paragraph, style(Heading1)
putdocx text ("Regression results")

/* Describe the model. */
putdocx textblock begin
Below, we fit a linear regression of birthweight on the mother's age and 
whether she smokes.
putdocx textblock end

regress bwt i.smoke age, cformat(%9.2f)
// Add a title to the table of estimation results 
putdocx table bweight = etable, title("Linear regression of birthweight")

/* Remove the empty line that read "smoke" */
putdocx table bweight(3,.), drop 
/* Add a background color to all columns of rows two and four */
putdocx table bweight(2 4,.), shading(lightgray)

putdocx textblock begin
We find that on average, infants whose mothers smoked tend to weigh less, and 
the mother's age is not a statistically significant factor.
putdocx textblock end

putdocx save bwreport, replace
