version 17
use low, clear

/* Create a document with a footer, including chapter and page numbers.
Use a colon to separate chapter and page numbers. */
putdocx begin, footer(foot1) pagenum(decimal,1,Heading1 ,colon)

/* Add a table to the footer */
putdocx table ftr = (1,2), tofooter(foot1) border(all,nil)
putdocx table ftr(1,1)= ("Birthweight report")
putdocx table ftr(1,2)=("Chapter "), pagenumber halign(right)

putdocx paragraph, style(Title)
putdocx text ("Analysis of birthweights")

putdocx pagebreak

putdocx paragraph, style(Heading1)
putdocx text ("Data")

putdocx textblock begin
We have data on birthweights from Hosmer, Lemeshow, and Sturdivant(2013, 24). This dataset includes some demographic information on each infant's mother, 
such as her age and race. We also have relevant medical history, including her 
weight, history of hypertension and premature labor, and the number of 
physician visits during her first trimester.
putdocx textblock end

putdocx paragraph, style(Heading1)
putdocx text ("Summary statistics")

summarize bwt

putdocx textblock begin
We have the recorded weight for <<dd_docx_display: r(N)>> babies with an 
average birthweight of <<dd_docx_display: %5.2f r(mean)>> grams.
putdocx textblock end

local total = r(N)
count if smoke==1

putdocx textblock append
 There are <<dd_docx_display: r(N)>> mothers who smoked during pregnancy, and <<dd_docx_display: `total'-r(N)>> who did not. Below we graph the mean 
birthweight for babies with mothers who smoke versus those who do not, 
separately for mothers with and without a history of hypertension.
putdocx textblock end

graph hbar bwt, over(ht) over(smoke) asyvars ///
            ytitle(Average birthweight (grams)) title(Baby birthweights) ///
	subtitle(by mother's smoking status and history of hypertension)
graph export bweight.png, replace

putdocx paragraph
putdocx image bweight.png, width(4) 

putdocx pagebreak

putdocx paragraph, style(Heading1)
putdocx text ("Regression results")

putdocx textblock begin
Below, we fit a linear regression of birthweight on the mother's age and 
whether she smokes.
putdocx textblock end

regress bwt i.smoke age, noheader cformat(%9.2f)
putdocx table bweight = etable, title("Linear regression of birthweight")

putdocx table bweight(3,.), drop 

putdocx table bweight(2 4,.), shading(lightgray)

putdocx textblock begin
We find that on average, infants whose mothers smoked tend to weigh less, and 
the mother's age is not a statistically significant factor.
putdocx textblock end

putdocx save bwreport, replace

